==> deepin-log-viewer_5.8.32.orig.tar.xz: deepin-log-viewer-5.8.32/translations/deepin-log-viewer_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>在檔案管理器中顯示</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>清除日誌</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>重新整理</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>您確定要清除該日誌嗎？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>今天</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>近三天</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>近一週</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>近一個月</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>近三個月</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">匯出</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>匯 出</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>緊急</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>嚴重警告</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>嚴重</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>注意</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>訊息</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>除錯</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>登入</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>開機</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>非常嚴重</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>跟蹤</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>正在導出...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>匯出成功</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>匯出失敗</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>匯出文件</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>週期：</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>級別：</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation> 應用程式列表：</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>登入訊息</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>事件類型：</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>主機名稱：</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>行程號：</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>動作：</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>使用者名稱：</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>開機記錄</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>關機記錄</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>登入訊息</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>除錯</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>訊息</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>緊急</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>嚴重警告</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>嚴重</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>注意</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>跟蹤</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>非常嚴重</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>日誌檔案為空</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>日誌收集工具</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>日誌收集工具是一款查看系統日誌的小工具。</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>無搜尋結果</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>級別</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>行程</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>時間</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>訊息</translation>
    </message>
    <message>
        <source>User</source>
        <translation>主機名稱</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>行程號</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>來源</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>動作</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>狀態</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>事件類型</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>使用者名稱</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>級別：</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>行程：</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>時間：</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>訊息：</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>主機名稱：</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>行程號：</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>時間</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>系統日誌</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>核心日誌</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>啟動日誌</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg日誌</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>kwin日誌</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg日誌</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>應用程式日誌</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>開關機事件</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf日誌</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.0.1.tar.xz: deepin-log-viewer-6.0.1/translations/deepin-log-viewer_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>在檔案管理器中顯示</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>清除日誌</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>重新整理</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>您確定要清除該日誌嗎？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>今天</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>近三天</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>近一週</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>近一個月</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>近三個月</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">匯出</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>匯 出</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>緊急</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>嚴重警告</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>嚴重</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>注意</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>訊息</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>除錯</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>登入</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>開機</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>非常嚴重</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>跟蹤</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>正在匯出...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>匯出成功</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>匯出失敗</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>匯出文件</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>週期：</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>級別：</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation> 應用程式列表：</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>登入訊息</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>事件類型：</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>主機名稱：</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>行程號：</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>動作：</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>使用者名稱：</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>開機記錄</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>關機記錄</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>登入訊息</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>除錯</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>訊息</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>緊急</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>嚴重警告</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>嚴重</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>注意</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>跟蹤</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>非常嚴重</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>日誌檔案為空</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>日誌收集工具</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>日誌收集工具是一款查看系統日誌的小工具。</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>無搜尋結果</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>級別</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>行程</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>時間</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>訊息</translation>
    </message>
    <message>
        <source>User</source>
        <translation>主機名稱</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>行程號</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>來源</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>動作</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>狀態</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>事件類型</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>使用者名稱</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>級別：</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>行程：</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>時間：</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>訊息：</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>主機名稱：</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>行程號：</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>時間</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>系統日誌</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>核心日誌</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>啟動日誌</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg日誌</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>kwin日誌</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg日誌</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>應用程式日誌</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>開關機事件</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf日誌</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>重新整理頻率</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>每10秒</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>每1分鐘</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>每5分鐘</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>不重新整理</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>全部匯出</translation>
    </message>
    <message>
        <source>System Logs</source>
        <translation>系統全部日誌</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>立即重新整理</translation>
    </message>
</context>
</TS>
